/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id:
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.bc.filetransfer.listeners;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.bc.filetransfer.FileTransferConstants;
import org.ow2.petals.bc.filetransfer.service.GetFilesService;
import org.ow2.petals.bc.filetransfer.service.IFileService;
import org.ow2.petals.bc.filetransfer.service.SetFileService;
import org.ow2.petals.bc.filetransfer.service.StandardWriteService;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.listener.AbstractJBIListener;

/**
 * The file transfer BC JBI listener. Writes a file to hard disk on incoming JBI
 * message.
 * 
 * @version
 * @since Petals 2.0
 * @author eBMWebsourcing
 * 
 */

public class FileTransferJBIListener extends AbstractJBIListener {

    /**
     * Process the exchange : copy the received elements
     */
    @Override
    public void onJBIMessage(Exchange exchange) {
        IFileService fileService = null;
        // Fault ignored
        if (exchange.isActiveStatus()) {
            if (exchange.getFault() == null) {
                if (exchange.getOperation() != null
                        && FileTransferConstants.GET_FILES_OPERATION.equalsIgnoreCase(exchange
                                .getOperation().getLocalPart())) {
                    fileService = new GetFilesService(this.getExtensions(), this.getLogger());
                } else if (exchange.getOperation() != null
                        && FileTransferConstants.GET_FILE_OPERATION.equalsIgnoreCase(exchange
                                .getOperation().getLocalPart())) {
                    fileService = new GetFilesService(this.getExtensions(), this.getLogger());
                } else if (exchange.getOperation() != null
                        && FileTransferConstants.SET_FILE_OPERATION.equalsIgnoreCase(exchange
                                .getOperation().getLocalPart())) {
                    fileService = new SetFileService(this.getExtensions(), this.getLogger(), this
                            .getComponent());
                } else {
                    fileService = new StandardWriteService(this.getExtensions(), this.getLogger(),
                            this.getComponent());
                }
                fileService.process(exchange);
            } else {
                try {
                    exchange.setDoneStatus();
                } catch (MessagingException e) {
                    this.getLogger().severe("Unable to set the exchange to done status");
                    exchange
                            .setError(new Exception("Unable to set the exchange to done status", e));
                }
            }
        }
    }
}
