package org.ow2.petals.bc.filetransfer.service;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.logging.Logger;

import javax.jbi.JBIException;
import javax.jbi.messaging.Fault;
import javax.jbi.messaging.MessagingException;

import org.ow2.petals.bc.filetransfer.FileTransferConstants;
import org.ow2.petals.component.framework.api.configuration.ConfigurationExtensions;
import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.util.FileNamePatternUtil;
import org.ow2.petals.component.framework.util.SourceHelper;
import org.ow2.petals.component.framework.util.XMLUtil;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

public abstract class AbstractGetOperationService extends AbstractFileService {

    public AbstractGetOperationService(ConfigurationExtensions extensions, Logger logger) {
        super(extensions, logger);
    }

    /**
     * extract in the exchange request the filepattern to use
     * 
     * @param exchange
     * @return
     * @throws MessagingException
     *             error while accessing the Exchange
     * @throws FileNotFoundException
     *             element not found in the XML request
     */
    protected String extractFilePattern(Exchange exchange) throws MessagingException,
            FileNotFoundException {
        Document doc = exchange.getInMessageContentAsDocument();
        Node rootNode = doc.getFirstChild();
        Node pattern = null;
        if (rootNode != null) {
            pattern = XMLUtil.findChild(rootNode, "filepattern", null, false);
        }
        if (pattern == null) {
            throw new FileNotFoundException(
                    "incorrect file filter found in getFile(s)/getFile(s)Request/filepattern");
        }
        return pattern.getTextContent();
    }

    /**
     * return the files contained in the READ DIRECTORY set in the extensions,
     * using the given filePattern
     * 
     * @param extensions
     * @return
     */
    protected File[] listFiles(File readDir, String filePattern) {
        return readDir.listFiles(FileNamePatternUtil.getInstance().buildFileNameFilterFromWildChar(
                filePattern));
    }

    protected void setIOFaultOnExchange(Exchange exchange, String ioMessage) throws JBIException {
        StringBuffer faultMessage = new StringBuffer();
        faultMessage.append("<tns:ioFault xmlns:tns='");
        faultMessage.append(FileTransferConstants.GET_FILES_SERVICE_NS);
        faultMessage.append("'><tns:message>");
        faultMessage.append(ioMessage);
        faultMessage.append("</tns:message></tns:ioFault>");
        Fault fault = exchange.createFault();
        try {
            fault.setContent(SourceHelper.createSource(faultMessage.toString()));
            exchange.setFault(fault);
        } catch (PEtALSCDKException e) {
            throw new JBIException(e.getMessage());
        }
    }
}
